@@ -70,6 +70,8 @@ class MonographSearchIndex extends SubmissionSearchIndex
      * @param int $monographId
      * @param int $type
      * @param SubmissionFile $submissionFile
+     *
+     * @hook MonographSearchIndex::submissionFileChanged [[$monographId, $type, $submissionFile->getId()]]
      */
     public function submissionFileChanged($monographId, $type, $submissionFile)
     {
@@ -119,6 +121,9 @@ class MonographSearchIndex extends SubmissionSearchIndex
      * Index monograph metadata.
      *
      * @param Submission $submission
+     *
+     * @hook MonographSearchIndex::submissionMetadataChanged [[$submission]]
+     * @hook MonographSearchIndex::monographMetadataChanged [[$submission]]
      */
     public function submissionMetadataChanged($submission)
     {
@@ -137,8 +142,8 @@ class MonographSearchIndex extends SubmissionSearchIndex
                 array_values((array) $author->getData('givenName')),
                 array_values((array) $author->getData('familyName')),
                 array_values((array) $author->getData('preferredPublicName')),
-                array_values(array_map('strip_tags', (array) $author->getData('affiliation'))),
-                array_values(array_map('strip_tags', (array) $author->getData('biography')))
+                array_values(array_map(strip_tags(...), (array) $author->getData('affiliation'))),
+                array_values(array_map(strip_tags(...), (array) $author->getData('biography')))
             );
         }
 
@@ -160,6 +165,8 @@ class MonographSearchIndex extends SubmissionSearchIndex
      * Index all monograph files (galley files).
      *
      * @param Submission $monograph
+     *
+     * @hook MonographSearchIndex::submissionFilesChanged [[$monograph]]
      */
     public function submissionFilesChanged($monograph)
     {
@@ -223,6 +230,8 @@ class MonographSearchIndex extends SubmissionSearchIndex
      *
      * @param int $type optional
      * @param int $assocId optional
+     *
+     * @hook MonographSearchIndex::submissionFileDeleted [[$monographId, $type, $assocId]]
      */
     public function submissionFileDeleted($monographId, $type = null, $assocId = null)
     {
@@ -237,6 +246,8 @@ class MonographSearchIndex extends SubmissionSearchIndex
 
     /**
      * @copydoc SubmissionSearchIndex::submissionChangesFinished()
+     *
+     * @hook MonographSearchIndex::monographChangesFinished []
      */
     public function submissionChangesFinished()
     {
@@ -272,6 +283,8 @@ class MonographSearchIndex extends SubmissionSearchIndex
      *  implementation does not support press-specific re-indexing
      *  as index data is not partitioned by press.
      * @param array $switches Optional index administration switches.
+     *
+     * @hook MonographSearchIndex::rebuildIndex [[$log]]
      */
     public function rebuildIndex($log = false, $press = null, $switches = [])
     {
