@@ -17,7 +17,6 @@
 
 namespace APP\sushi;
 
-use APP\core\Services;
 use APP\facades\Repo;
 use Illuminate\Support\Collection;
 use PKP\components\forms\FieldOptions;
@@ -195,7 +194,7 @@ class TR extends CounterR5Report
         // do not consider section_type filter now, but later when grouping by submission
         // do not consider metric_type filter now, but for display
 
-        $statsService = Services::get('sushiStats');
+        $statsService = app()->get('sushiStats');
         $metricsQB = $statsService->getQueryBuilder($params);
         // consider attributes to group the metrics by
         $groupBy = ['m.' . PKPStatisticsHelper::STATISTICS_DIMENSION_SUBMISSION_ID];
