@@ -64,6 +64,8 @@
 		$form.find('.datepicker').each(function() {
 			var $this = $(this);
 			$this.datepicker({
+				changeMonth: true,
+				changeYear: true,				
 				altField: '#' + $this.prop('id') + '-altField',
 				altFormat: 'yy-mm-dd',
 				dateFormat: $('#' + $this.prop('id') + '-altField')
@@ -553,7 +555,9 @@
 		$form.find('.hasDatepicker').datepicker('hide');
 		if (this.formChangesTracked) {
 			if (!confirm(pkp.localeKeys['form.dataHasChanged'])) {
-				informationObject.closePermitted = false;
+				if (informationObject) {
+					informationObject.closePermitted = false;
+				}
 				return false;
 			} else {
 				this.trigger('unregisterAllForms');
