@@ -3,8 +3,8 @@
 /**
  * @file pages/catalog/CatalogBookHandler.php
  *
- * Copyright (c) 2014-2021 Simon Fraser University
- * Copyright (c) 2003-2021 John Willinsky
+ * Copyright (c) 2014-2025 Simon Fraser University
+ * Copyright (c) 2003-2025 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class CatalogBookHandler
@@ -19,7 +19,6 @@ namespace APP\pages\catalog;
 
 use APP\core\Application;
 use APP\core\Request;
-use APP\core\Services;
 use APP\facades\Repo;
 use APP\handler\Handler;
 use APP\monograph\Chapter;
@@ -31,11 +30,12 @@ use APP\publication\Publication;
 use APP\security\authorization\OmpPublishedSubmissionAccessPolicy;
 use APP\submission\Submission;
 use APP\template\TemplateManager;
-use PKP\citation\CitationDAO;
+use PKP\core\Core;
 use PKP\core\PKPApplication;
 use PKP\core\PKPRequest;
 use PKP\db\DAORegistry;
 use PKP\facades\Locale;
+use PKP\orcid\OrcidManager;
 use PKP\plugins\Hook;
 use PKP\plugins\PluginRegistry;
 use PKP\security\authorization\ContextRequiredPolicy;
@@ -44,23 +44,16 @@ use PKP\submission\Genre;
 use PKP\submission\GenreDAO;
 use PKP\submission\PKPSubmission;
 use PKP\submissionFile\SubmissionFile;
+use PKP\userGroup\UserGroup;
+use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
 
 class CatalogBookHandler extends Handler
 {
-    /** @var Publication The requested publication */
-    public $publication;
-
-    /** @var null|Chapter The requested chapter */
-    public $chapter = null;
-
-    /** @var array this array contains ids of all publications, those contain the requested chapter */
-    public $chapterPublicationIds = [];
-
-    /** @var bool Is this a request for a specific version */
-    public $isVersionRequest = false;
-
-    /** @var bool Is this a request for a chapter */
-    public $isChapterRequest = false;
+    public Publication $publication;
+    public ?Chapter $chapter = null;
+    public array $chapterPublicationIds = [];
+    public bool $isVersionRequest = false;
+    public bool $isChapterRequest = false;
 
     //
     // Overridden functions from PKPHandler
@@ -88,6 +81,8 @@ class CatalogBookHandler extends Handler
      *
      * @param array $args
      * @param Request $request
+     *
+     * @hook CatalogBookHandler::book [[&$request, &$submission, &$this->publication, &$this->chapter]]
      */
     public function book($args, $request)
     {
@@ -96,9 +91,15 @@ class CatalogBookHandler extends Handler
         $user = $request->getUser();
         $this->setupTemplate($request, $submission);
 
-        // Serve 404 if no submission available OR submission is unpublished and no user is logged in OR submission is unpublished and we have a user logged in but the user does not have access to preview
-        if (!$submission || ($submission->getData('status') !== PKPSubmission::STATUS_PUBLISHED && !$user) || ($submission->getData('status') !== PKPSubmission::STATUS_PUBLISHED && $user && !Repo::submission()->canPreview($user, $submission))) {
-            $request->getDispatcher()->handle404();
+        // Serve 404 if no submission available
+        // OR submission is unpublished and no user is logged in
+        // OR submission is unpublished, and we have a user logged in but the user does not have access to preview
+        if (
+            !$submission ||
+            ($submission->getData('status') !== PKPSubmission::STATUS_PUBLISHED && !$user) ||
+            ($submission->getData('status') !== PKPSubmission::STATUS_PUBLISHED && $user && !Repo::submission()->canPreview($user, $submission))
+        ) {
+            throw new NotFoundHttpException();
         }
 
         // Get the requested publication or default to the current publication
@@ -117,7 +118,7 @@ class CatalogBookHandler extends Handler
         }
 
         if (!$this->publication || ($this->publication->getData('status') !== PKPSubmission::STATUS_PUBLISHED && !Repo::submission()->canPreview($user, $submission))) {
-            $request->getDispatcher()->handle404();
+            throw new NotFoundHttpException();
         }
 
         // If the publication has been reached through an outdated
@@ -140,7 +141,7 @@ class CatalogBookHandler extends Handler
 
         if ($this->isChapterRequest) {
             if (!$this->chapter->isPageEnabled()) {
-                $request->getDispatcher()->handle404();
+                throw new NotFoundHttpException();
             }
             $chapterAuthors = $this->chapter->getAuthors();
             $chapterAuthors = $chapterAuthors->toArray();
@@ -173,9 +174,7 @@ class CatalogBookHandler extends Handler
             return empty($a) || strtotime((string) $b->getData('datePublished')) < strtotime((string) $a->getData('datePublished')) ? $b : $a;
         }, 0);
 
-        $userGroups = Repo::userGroup()->getCollector()
-            ->filterByContextIds([$submission->getData('contextId')])
-            ->getMany();
+        $userGroups = UserGroup::withContextIds([$submission->getData('contextId')])->get();
 
         $templateMgr->assign([
             'isChapterRequest' => $this->isChapterRequest,
@@ -192,7 +191,7 @@ class CatalogBookHandler extends Handler
         foreach ($this->publication->getData('publicationFormats') as $format) {
             if ($format->getIsAvailable()) {
                 $availablePublicationFormats[] = $format;
-                if ($format->getRemoteURL()) {
+                if ($format->getData('urlRemote')) {
                     $availableRemotePublicationFormats[] = $format;
                 }
             }
@@ -203,7 +202,7 @@ class CatalogBookHandler extends Handler
         ]);
 
         // Assign chapters (if they exist)
-        /** @var ChapterDAO */
+        /** @var ChapterDAO $chapterDao */
         $chapterDao = DAORegistry::getDAO('ChapterDAO');
         $templateMgr->assign('chapters', $chapterDao->getByPublicationId($this->publication->getId())->toAssociativeArray());
 
@@ -227,19 +226,15 @@ class CatalogBookHandler extends Handler
         ]);
 
         // Citations
-        if ($this->publication->getData('citationsRaw')) {
-            /** @var CitationDAO */
-            $citationDao = DAORegistry::getDAO('CitationDAO');
-            $parsedCitations = $citationDao->getByPublicationId($this->publication->getId());
-            $templateMgr->assign([
-                'citations' => $parsedCitations->toArray(),
-                'parsedCitations' => $parsedCitations, // compatible with older themes
-            ]);
-        }
+        $parsedCitations = $this->publication->getData('citations');
+        $templateMgr->assign([
+            'citations' => $parsedCitations,
+            'parsedCitations' => $parsedCitations, // compatible with older themes
+        ]);
 
         // Retrieve editors for an edited volume
         $editors = [];
-        if ($submission->getWorkType() == $submission::WORK_TYPE_EDITED_VOLUME) {
+        if ($submission->getData('workType') == $submission::WORK_TYPE_EDITED_VOLUME) {
             foreach ($this->publication->getData('authors') as $author) {
                 if ($author->getIsVolumeEditor()) {
                     $editors[] = $author;
@@ -291,10 +286,21 @@ class CatalogBookHandler extends Handler
             'licenseUrl' => $this->publication->getData('licenseUrl'),
         ]);
 
+        // Add Orcid icon
+        $templateMgr->assign([
+            'orcidIcon' => OrcidManager::getIcon(),
+            'orcidUnauthenticatedIcon' => OrcidManager::getUnauthenticatedIcon(),
+        ]);
+
+        // Add ROR icon
+        $rorIconPath = Core::getBaseDir() . '/' . PKP_LIB_PATH . '/templates/images/ror.svg';
+        $rorIdIcon = file_exists($rorIconPath) ? file_get_contents($rorIconPath) : '';
+        $templateMgr->assign('rorIdIcon', $rorIdIcon);
+
         // Ask robots not to index outdated versions and point to the canonical url for the latest version
-        if ($this->publication->getId() !== $submission->getCurrentPublication()->getId()) {
+        if ($this->publication->getId() != $submission->getData('currentPublicationId')) {
             $templateMgr->addHeader('noindex', '<meta name="robots" content="noindex">');
-            $url = $request->getDispatcher()->url($request, PKPApplication::ROUTE_PAGE, null, 'catalog', 'book', $submission->getBestId());
+            $url = $request->getDispatcher()->url($request, PKPApplication::ROUTE_PAGE, null, 'catalog', 'book', [$submission->getBestId()]);
             $templateMgr->addHeader('canonical', '<link rel="canonical" href="' . $url . '">');
         }
 
@@ -328,10 +334,15 @@ class CatalogBookHandler extends Handler
      * @param array $args
      * @param Request $request
      * @param bool $view True iff inline viewer should be used, if available
+     *
+     * @hook CatalogBookHandler::view [[&$this, &$submission, &$publicationFormat, &$submissionFile]]
+     * @hook CatalogBookHandler::download [[&$this, &$submission, &$publicationFormat, &$submissionFile, &$inline]]
+     * @hook FileManager::downloadFileFinished [[&$returner]]
      */
     public function download($args, $request, $view = false)
     {
         $dispatcher = $request->getDispatcher();
+        /* @var Submission $submission */
         $submission = $this->getAuthorizedContextObject(Application::ASSOC_TYPE_SUBMISSION);
         $this->setupTemplate($request, $submission);
         $press = $request->getPress();
@@ -341,16 +352,15 @@ class CatalogBookHandler extends Handler
         if ($subPath === 'version') {
             $publicationId = array_shift($args);
             $representationId = array_shift($args);
-            $bestFileId = array_shift($args);
         } else {
             $publicationId = $submission->getCurrentPublication()->getId();
             $representationId = $subPath;
-            $bestFileId = array_shift($args);
         }
+        $bestFileId = array_shift($args);
 
         $publicationFormat = Application::get()->getRepresentationDAO()->getByBestId($representationId, $publicationId);
-        if (!$publicationFormat || !$publicationFormat->getIsAvailable() || $publicationFormat->getRemoteURL()) {
-            $dispatcher->handle404();
+        if (!$publicationFormat || !$publicationFormat->getIsAvailable() || $publicationFormat->getData('urlRemote')) {
+            throw new NotFoundHttpException();
         }
 
         $publication = null;
@@ -361,10 +371,12 @@ class CatalogBookHandler extends Handler
             }
         }
 
-        if (empty($publication)
-                || $publication->getData('status') !== PKPSubmission::STATUS_PUBLISHED
-                || $publicationFormat->getData('publicationId') !== $publication->getId()) {
-            $dispatcher->handle404();
+        if (
+            empty($publication) ||
+            $publication->getData('status') !== PKPSubmission::STATUS_PUBLISHED ||
+            $publicationFormat->getData('publicationId') !== $publication->getId()
+        ) {
+            throw new NotFoundHttpException();
         }
 
         $submissionFile = Repo::submissionFile()
@@ -374,25 +386,26 @@ class CatalogBookHandler extends Handler
                 $submission->getId()
             );
         if (!$submissionFile) {
-            $dispatcher->handle404();
+            throw new NotFoundHttpException();
         }
 
         $path = $submissionFile->getData('path');
-        $filename = Services::get('file')->formatFilename($path, $submissionFile->getLocalizedData('name'));
+        $filename = app()->get('file')->formatFilename($path, $submissionFile->getLocalizedData('name'));
         switch ($submissionFile->getData('assocType')) {
             case Application::ASSOC_TYPE_PUBLICATION_FORMAT: // Publication format file
                 if ($submissionFile->getData('assocId') != $publicationFormat->getId() || $submissionFile->getDirectSalesPrice() === null) {
-                    $dispatcher->handle404();
+                    throw new NotFoundHttpException();
                 }
                 break;
             case Application::ASSOC_TYPE_SUBMISSION_FILE: // Dependent file
                 $genreDao = DAORegistry::getDAO('GenreDAO'); /** @var GenreDAO $genreDao */
-                $genre = $genreDao->getById($submissionFile->getGenreId());
+                $genre = $genreDao->getById($submissionFile->getData('genreId'));
                 if (!$genre->getDependent()) {
-                    $dispatcher->handle404();
+                    throw new NotFoundHttpException();
                 }
-                return Services::get('file')->download($submissionFile->getData('fileId'), $filename);
-            default: $dispatcher->handle404();
+                return app()->get('file')->download($submissionFile->getData('fileId'), $filename);
+            default:
+                throw new NotFoundHttpException();
         }
 
         $urlPath = [$submission->getBestId()];
@@ -404,10 +417,12 @@ class CatalogBookHandler extends Handler
         $urlPath[] = $submissionFile->getBestId();
 
         $chapterDao = DAORegistry::getDAO('ChapterDAO'); /** @var ChapterDAO $chapterDao */
-        $chapter = $chapterDao->getChapter($submissionFile->getData('chapterId'));
+        $chapterId = $submissionFile->getData('chapterId');
+        $chapter = $chapterId ? $chapterDao->getChapter((int) $chapterId) : null;
         $templateMgr = TemplateManager::getManager($request);
         $templateMgr->assign([
             'publishedSubmission' => $submission,
+            'publication' => $publication,
             'publicationFormat' => $publicationFormat,
             'submissionFile' => $submissionFile,
             'chapter' => $chapter,
@@ -432,16 +447,17 @@ class CatalogBookHandler extends Handler
 
             // Inline viewer not available, or viewing not wanted.
             // Download or show the file.
-            $inline = $request->getUserVar('inline') ? true : false;
+            $inline = (bool)$request->getUserVar('inline');
             if (Hook::call('CatalogBookHandler::download', [&$this, &$submission, &$publicationFormat, &$submissionFile, &$inline])) {
                 // If the plugin handled the hook, prevent further default activity.
                 exit;
             }
 
-            // if the file is a publication format file (i.e. not a dependent file e.g. CSS or images), fire an usage event.
+            // if the file is a publication format file (i.e. not a dependent file e.g. CSS or images),
+            // fire a usage event.
             if ($submissionFile->getData('assocId') == $publicationFormat->getId()) {
                 $assocType = Application::ASSOC_TYPE_SUBMISSION_FILE;
-                /** @var GenreDAO */
+                /** @var GenreDAO $genreDao */
                 $genreDao = DAORegistry::getDAO('GenreDAO');
                 $genre = $genreDao->getById($submissionFile->getData('genreId'));
                 // TO-DO: is this correct ?
@@ -452,7 +468,7 @@ class CatalogBookHandler extends Handler
             }
             $returner = true;
             Hook::call('FileManager::downloadFileFinished', [&$returner]);
-            return Services::get('file')->download($submissionFile->getData('fileId'), $filename, $inline);
+            return app()->get('file')->download($submissionFile->getData('fileId'), $filename, $inline);
         }
 
         // Fall-through: user needs to pay for purchase.
@@ -506,7 +522,7 @@ class CatalogBookHandler extends Handler
     {
         if ($chapterId > 0) {
             $this->isChapterRequest = true;
-            /** @var ChapterDAO */
+            /** @var ChapterDAO $chapterDao */
             $chapterDao = DAORegistry::getDAO('ChapterDAO');
             $chapters = $chapterDao->getBySourceChapterId($chapterId);
             $chapters = $chapters->toAssociativeArray();
@@ -524,7 +540,7 @@ class CatalogBookHandler extends Handler
             }
 
             if (null === $this->chapter) {
-                $request->getDispatcher()->handle404();
+                throw new NotFoundHttpException();
             }
         }
     }
@@ -535,7 +551,7 @@ class CatalogBookHandler extends Handler
     protected function setChapterPublicationIds(): void
     {
         if ($this->chapter && $this->isChapterRequest) {
-            /** @var ChapterDAO */
+            /** @var ChapterDAO $chapterDao */
             $chapterDao = DAORegistry::getDAO('ChapterDAO');
             $chapters = $chapterDao->getBySourceChapterId($this->chapter->getSourceChapterId());
             $chapters = $chapters->toAssociativeArray();
@@ -557,7 +573,7 @@ class CatalogBookHandler extends Handler
      */
     protected function getSourceChapter(Submission $submission): ?Chapter
     {
-        /** @var ChapterDAO */
+        /** @var ChapterDAO $chapterDao */
         $chapterDao = DAORegistry::getDAO('ChapterDAO');
         $chapters = $chapterDao->getBySourceChapterId($this->chapter->getSourceChapterId());
         $chapters = $chapters->toAssociativeArray();
