@@ -25,16 +25,11 @@ switch ($op) {
     case 'series':
     case 'settings':
     case 'access':
-        define('HANDLER_CLASS', 'APP\pages\management\SettingsHandler');
-        break;
+        return new APP\pages\management\SettingsHandler();
     case 'tools':
     case 'importexport':
     case 'statistics':
     case 'permissions':
     case 'resetPermissions':
-        define('HANDLER_CLASS', 'PKP\pages\management\PKPToolsHandler');
-        break;
-    case 'navigation':
-        define('HANDLER_CLASS', 'APP\pages\management\NavigationHandler');
-        break;
+        return new PKP\pages\management\PKPToolsHandler();
 }
