@@ -27,6 +27,8 @@ class SitemapHandler extends PKPSitemapHandler
 {
     /**
      * @copydoc PKPSitemapHandler::_createContextSitemap()
+     *
+     * @hook SitemapHandler::createPressSitemap [[&$doc]]
      */
     public function _createContextSitemap($request)
     {
@@ -96,7 +98,7 @@ class SitemapHandler extends PKPSitemapHandler
             ->filterByContextIds([$pressId])
             ->getMany();
         foreach ($seriesResult as $series) {
-            $root->appendChild($this->_createUrlTree($doc, $request->url($press->getPath(), 'catalog', 'series', $series->getPath())));
+            $root->appendChild($this->_createUrlTree($doc, $request->url($press->getPath(), 'catalog', 'series', [$series->getPath()])));
         }
         // Browse by categories
         $categories = Repo::category()->getCollector()
@@ -104,7 +106,7 @@ class SitemapHandler extends PKPSitemapHandler
             ->getMany();
 
         foreach ($categories as $category) {
-            $root->appendChild($this->_createUrlTree($doc, $request->url($press->getPath(), 'catalog', 'category', $category->getPath())));
+            $root->appendChild($this->_createUrlTree($doc, $request->url($press->getPath(), 'catalog', 'category', [$category->getPath()])));
         }
 
         $doc->appendChild($root);
